==> mailcheck-maildir-0.1.tar.bz2: mailcheck-maildir-0.1/mailcheck.cpp <==
#include <iostream>
#include <cstdio>
#include <cstdlib>
#include <ctime>
#include <cstring>
#include <dirent.h>
#include <unistd.h>
#include <errno.h>
#include <vector>
#include <string>
using namespace std;

int check_mail(string fname)
{
    DIR* dp;
    dirent* ep;
    dp = opendir((fname + "/new").c_str());
    if (!dp) {
	//cout << "Nemuzu otevrit " << fname << "/new" << endl;
	return 0;
    }

    int nmail = 0;
    while ((ep = readdir(dp))) {
	if (ep->d_type & DT_REG)
	    nmail++;
    }

    closedir(dp);
    return nmail;
}

int porovnej(const void *a, const void *b)
{
    return strcmp(((string*)a)->c_str(),((string*)b)->c_str());
}

int main(int argc, char *argv[])
{
    int pocet_celkem = 0;
    vector<string> mbox;
    
    DIR* dp;
    dirent* ep;
    
    char *maildir = 0;
    {
	const char* home;
	if (!(home = getenv("HOME"))) {
	    cerr << "Nemas home???\n";
	    return -1;
	}
	maildir = (char*) malloc(strlen(home) + 10);
	if (!maildir) {
	    cerr << "Chyba malloc\n";
	    return -1;
	}
	strcpy(maildir,home);
	strcat(maildir,"/Mail");
    }
    
    dp = opendir(maildir);
    if (!dp) {
	cout << "Nenasel jsem ~/Mail !!!\n";
    } else {
	while ((ep = readdir(dp))) {
	    if (ep->d_type & DT_DIR && strlen(ep->d_name) && strcmp(ep->d_name,"..") &&
		    ep->d_name[0] == '.') {
		mbox.push_back(string(maildir) + "/" + ep->d_name);
	    }
	}
	closedir(dp);
    }
    if (maildir) free(maildir);
    sort(mbox.begin(), mbox.end());

    for (vector<string>::iterator i = mbox.begin(); i != mbox.end(); i++) {
	int pocet = check_mail(*i);
	if (pocet) {
	    pocet_celkem += pocet;
	    cout << "Mas ";
	    printf("%4i",pocet);
	    cout << " " << ({
		    char* ret;
		    if (pocet == 1) {
		    ret = "   novy mail";
		    } else if (pocet>1 && pocet<5) {
		    ret = "  nove maily";
		    } else {
		    ret = "novych mailu";
		    }
		    ret;
		    }) << " v " << *i << endl;
	}
    }

    if (pocet_celkem) {
	cout << " --\n";
	cout << "Mas celkem " << pocet_celkem << " " << ({
		char* ret;
		if (pocet_celkem == 1) {
		ret = "novy mail";
		} else if (pocet_celkem>1 && pocet_celkem<5) {
		ret = "nove maily";
		} else {
		ret = "novych mailu";
		}
		ret;
		}) << "." << endl;
    }
}

==> mailcheck-maildir-0.2.tar.bz2: mailcheck-maildir-0.2/mailcheck.cpp <==
#include <iostream>
#include <cstdio>
#include <cstdlib>
#include <ctime>
#include <cstring>
#include <dirent.h>
#include <unistd.h>
#include <errno.h>
#include <vector>
#include <string>
#include <sys/types.h>
#include <sys/stat.h>
using namespace std;

int check_mail(string fname)
{
    DIR* dp;
    dirent* ep;
    struct stat st;

    dp = opendir((fname + "/new").c_str());
    if (!dp) {
	//cout << "Nemuzu otevrit " << fname << "/new" << endl;
	return 0;
    }

    int nmail = 0;
    while ((ep = readdir(dp))) {
	if (stat((fname + "/new/" + ep->d_name).c_str(), &st)) {
	    perror("stat");
	    continue;
	}
	if (S_ISREG(st.st_mode))
	    nmail++;
    }

    closedir(dp);
    return nmail;
}

int porovnej(const void *a, const void *b)
{
    return strcmp(((string*)a)->c_str(),((string*)b)->c_str());
}

int main(int argc, char *argv[])
{
    int pocet_celkem = 0;
    vector<string> mbox;
    
    DIR* dp;
    dirent* ep;
    struct stat st;
    
    char *maildir = 0;
    {
	const char* home;
	if (!(home = getenv("HOME"))) {
	    cerr << "Nemas home???\n";
	    return -1;
	}
	maildir = (char*) malloc(strlen(home) + 10);
	if (!maildir) {
	    cerr << "Chyba malloc\n";
	    return -1;
	}
	strcpy(maildir,home);
	strcat(maildir,"/Mail");
    }
    
    dp = opendir(maildir);
    if (!dp) {
	cout << "Nenasel jsem ~/Mail !!!\n";
    } else {
	while ((ep = readdir(dp))) {
	    if (stat((string(maildir) + "/" + ep->d_name).c_str(), &st)) {
		perror("stat");
		continue;
	    }
	    if (S_ISDIR(st.st_mode) && strlen(ep->d_name) && strcmp(ep->d_name,"..") &&
		    ep->d_name[0] == '.') {
		mbox.push_back(string(maildir) + "/" + ep->d_name);
	    }
	}
	closedir(dp);
    }
    if (maildir) free(maildir);
    sort(mbox.begin(), mbox.end());

    for (vector<string>::iterator i = mbox.begin(); i != mbox.end(); i++) {
	int pocet = check_mail(*i);
	if (pocet) {
	    pocet_celkem += pocet;
	    cout << "Mas ";
	    printf("%4i",pocet);
	    cout << " " << ({
		    char* ret;
		    if (pocet == 1) {
		    ret = "   novy mail";
		    } else if (pocet>1 && pocet<5) {
		    ret = "  nove maily";
		    } else {
		    ret = "novych mailu";
		    }
		    ret;
		    }) << " v " << *i << endl;
	}
    }

    if (pocet_celkem) {
	cout << " --\n";
	cout << "Mas celkem " << pocet_celkem << " " << ({
		char* ret;
		if (pocet_celkem == 1) {
		ret = "novy mail";
		} else if (pocet_celkem>1 && pocet_celkem<5) {
		ret = "nove maily";
		} else {
		ret = "novych mailu";
		}
		ret;
		}) << "." << endl;
    }
    return (pocet_celkem)?0:1;
}
